@@ -51,12 +51,15 @@ static void colourgui_set_colour_widget(GladeXML *glade,
 		const char *widget_name, GdkColor *colour, gboolean ignore)
 {
 	static GdkColormap *colour_map = NULL;
-	GtkWidget *widget = glade_xml_get_widget(glade, widget_name);
-
+	GtkWidget *widget;
+	
+	if (!colour)
+	    return;
 	if (!colour_map)
 		colour_map = gdk_colormap_get_system();
 	g_return_if_fail(gdk_colormap_alloc_color(colour_map, colour,
 				TRUE, TRUE));
+	widget = glade_xml_get_widget(glade, widget_name);
 	/* gtk_color_button_set_color doesn't seem to cause a change signal so
 	 * explicitly raise one if necessary */
 	capplet_ignore_changes = TRUE;
@@ -72,16 +75,16 @@ static void colourgui_set_fgbg_colour_widgets(GladeXML *glade,
 		Options *colour_scheme, gboolean ignore)
 {
 	colourgui_set_colour_widget(glade, "foreground_colour",
-			colour_scheme_get_foreground_colour(colour_scheme, TRUE), ignore);
+			colour_scheme_get_foreground_colour(colour_scheme, FALSE), ignore);
 	colourgui_set_colour_widget(glade, "background_colour",
-			colour_scheme_get_background_colour(colour_scheme, TRUE), ignore);
+			colour_scheme_get_background_colour(colour_scheme, FALSE), ignore);
 }
 
 static void colourgui_set_cursor_colour_widget(GladeXML *glade,
 		Options *colour_scheme, gboolean ignore)
 {
 	colourgui_set_colour_widget(glade, "cursor_colour",
-			colour_scheme_get_cursor_colour(colour_scheme, TRUE), ignore);
+			colour_scheme_get_cursor_colour(colour_scheme, FALSE), ignore);
 }
 
 static void colourgui_set_all_palette_widgets(GladeXML *glade,
@@ -196,10 +199,8 @@ static void colourgui_set_fgbg_track_toggle(GladeXML *glade,
 			&& colour_scheme_get_palette_size(colour_scheme))
 	{
 		GdkColor *palette = colour_scheme_get_palette(colour_scheme);
-		GdkColor *fg = colour_scheme_get_foreground_colour(colour_scheme,
-				FALSE);
-		GdkColor *bg = colour_scheme_get_background_colour(colour_scheme,
-				FALSE);
+		GdkColor *fg = colour_scheme_get_foreground_colour(colour_scheme, TRUE);
+		GdkColor *bg = colour_scheme_get_background_colour(colour_scheme, TRUE);
 
 		if (fg && bg
 				&& gdk_color_equal(&palette[0], fg)
