@@ -28,29 +28,23 @@
 
 #include <gtk/gtk.h>
 
-/*
- * Standard gettext macros.
- */
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  define Q_(String) g_strip_context ((String), gettext (String))
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
+#if ENABLE_NLS
+#include <libintl.h>
+#define _(s) ((const char *) gettext(s))
 #else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define Q_(String) g_strip_context ((String), (String))
-#  define N_(String) (String)
+#define _(s) s
 #endif
+#define N_(s) s
+
+/*
+#include "gettext.h"
+#ifndef _
+#define _(String) gettext (String)
+#endif
+#ifndef N_
+#define N_(String) gettext_noop (String)
+#endif
+*/
 
 #define ACCEL_PATH "<roxterm>"
 
@@ -63,6 +57,12 @@
 */
 #define UNREF_LOG(a) a
 
+#define ROXTERM_ARG_ERROR g_quark_from_static_string("roxterm-arg-error-quark")
+
+enum {
+	ROXTermArgError
+};
+
 #endif /* DEFNS_H */
 
 /* vi:set sw=4 ts=4 noet cindent cino= */
