@@ -70,7 +70,7 @@ static gboolean run_via_dbus(DBusMessage *message)
 	 * from original instance */
 	if (!global_options_directory)
 	{
-		char *cwd = g_get_current_dir();
+		char *cwd = GET_CURRENT_DIR();
 		const char *d = "-d";
 
 		message = rtdbus_append_args(message,
@@ -79,7 +79,7 @@ static gboolean run_via_dbus(DBusMessage *message)
 				DBUS_TYPE_INVALID);
 		if (!message)
 			result = FALSE;
-		g_free(cwd);
+		FREE_CURRENT_DIR(cwd);
 	}
 	if (result && global_options_commandv)
 	{
