@@ -40,8 +40,8 @@ typedef struct MultiWin MultiWin;
  * scroll menu actions.
  */
 typedef GtkWidget *(*MultiTabFiller) (MultiWin * win, MultiTab * tab,
-	gpointer user_data_template, gpointer * new_user_data,
-	char **title, GtkWidget ** active_widget, GtkAdjustment **adjustment);
+    gpointer user_data_template, gpointer * new_user_data,
+    char **title, GtkWidget ** active_widget, GtkAdjustment **adjustment);
 
 /* Called when a tab is destroyed, with the data passed as new_user_data above
  */
@@ -54,20 +54,20 @@ typedef void (*MultiWinMenuSignalConnector) (MultiWin * win);
  * widget; the user_data is the data returned by MultiTabFiller's new_user_data.
  */
 typedef void (*MultiWinGeometryFunc) (gpointer user_data, GdkGeometry * geom,
-	GdkWindowHints * hints);
+    GdkWindowHints * hints);
 
 /* Size function. pwidth and pheight point to return values for width and
  * height in pixels of the core of the widget ie minus any borders */
 typedef enum {
-	MultiWin_GetActualSize,		/* Return the current actual size of the
-								   widget's core */
-	MultiWin_GetTargetSize,		/* Return the size it should be from
-								   config settings or whatever */
-	MultiWin_UpdateConfiguredSize	/* User has resized window; update config
-									   from current size */
+    MultiWin_GetActualSize,        /* Return the current actual size of the
+                                   widget's core */
+    MultiWin_GetTargetSize,        /* Return the size it should be from
+                                   config settings or whatever */
+    MultiWin_UpdateConfiguredSize    /* User has resized window; update config
+                                       from current size */
 } MultiWinSizeReason;
 typedef void (*MultiWinSizeFunc) (gpointer user_data, MultiWinSizeReason,
-		int *pwidth, int *pheight);
+        int *pwidth, int *pheight);
 
 /* Called when a tab is selected */
 typedef void (*MultiTabSelectionHandler) (gpointer user_data, MultiTab * tab);
@@ -78,16 +78,16 @@ typedef void (*MultiTabToNewWindowHandler)(MultiWin *win, MultiTab *tab);
 
 /* Called when the zoom factor is changed */
 typedef void (*MultiWinZoomHandler)(gpointer user_data, double zoom_factor,
-		int zoom_index);
+        int zoom_index);
 
 /* Called to find out whether to use menu shortcuts */
 typedef void (*MultiWinGetDisableMenuShortcuts)(gpointer user_data,
-	gboolean *general, gboolean *tabs);
+    gboolean *general, gboolean *tabs);
 
 /* As number of tabs and tab position can be set by user we need another
  * function to get these values */
 typedef void (*MultiWinInitialTabs)(gpointer user_data,
-		GtkPositionType *p_pos, int *p_num);
+        GtkPositionType *p_pos, int *p_num);
 
 /* A handler for delete-event */
 typedef void (*MultiWinDeleteHandler)(GtkWidget *, GdkEvent *, MultiWin *win);
@@ -98,10 +98,10 @@ typedef void (*MultiWinDeleteHandler)(GtkWidget *, GdkEvent *, MultiWin *win);
  * probably need to call multi_win_get_user_data_for_current_tab () */
 void
 multi_tab_init(MultiTabFiller filler, MultiTabDestructor destructor,
-	MultiWinMenuSignalConnector menu_signal_connector,
-	MultiWinGeometryFunc, MultiWinSizeFunc, MultiTabToNewWindowHandler,
-	MultiWinZoomHandler, MultiWinGetDisableMenuShortcuts, MultiWinInitialTabs,
-	MultiWinDeleteHandler);
+    MultiWinMenuSignalConnector menu_signal_connector,
+    MultiWinGeometryFunc, MultiWinSizeFunc, MultiTabToNewWindowHandler,
+    MultiWinZoomHandler, MultiWinGetDisableMenuShortcuts, MultiWinInitialTabs,
+    MultiWinDeleteHandler);
 
 /* Register a MultiTabSelectionHandler (see above) */
 void
@@ -116,6 +116,8 @@ GtkWidget *multi_tab_get_widget(MultiTab *);
 
 void multi_tab_set_title(MultiTab *, const char *);
 
+void multi_tab_set_name(MultiTab *, const char *);
+
 void multi_tab_popup_menu(MultiTab * tab, guint button, guint32 event_time);
 
 gpointer multi_tab_get_user_data(MultiTab *);
@@ -130,7 +132,7 @@ MultiWin *multi_tab_get_parent(MultiTab *tab);
 
 inline static GtkNotebook *multi_tab_get_notebook(MultiTab *tab)
 {
-	return multi_win_get_notebook(multi_tab_get_parent(tab));
+    return multi_win_get_notebook(multi_tab_get_parent(tab));
 }
 
 /* Adds reference to widget but label and menutree widgets are lost;
@@ -155,41 +157,45 @@ void multi_tab_move_to_new_window(MultiWin *win, MultiTab *tab, int position);
  * widget is under the pointer */
 MultiTab *multi_tab_get_tab_under_pointer(int x, int y);
 
+/* Make the tab flash orange or something */
+void multi_tab_draw_attention(MultiTab *tab);
+void multi_tab_cancel_attention(MultiTab *tab);
+
 /* In following functions a zoom_index of -1 means default */
 
 /* Create a new window with default settings, adding it to main list */
 MultiWin *multi_win_new_full(Options *shortcuts, int zoom_index,
-			     gpointer user_data_template, const char *geom,
-			     gboolean full_screen, int numtabs, GtkPositionType tab_pos);
+                 gpointer user_data_template, const char *geom,
+                 gboolean full_screen, int numtabs, GtkPositionType tab_pos);
 
 inline static MultiWin *multi_win_new_with_geom(Options *shortcuts,
-						int zoom_index, gpointer user_data_template,
-						const char *geom, int numtabs, GtkPositionType tab_pos)
+                        int zoom_index, gpointer user_data_template,
+                        const char *geom, int numtabs, GtkPositionType tab_pos)
 {
-	return multi_win_new_full(shortcuts, zoom_index,
-				  user_data_template, geom, FALSE, numtabs, tab_pos);
+    return multi_win_new_full(shortcuts, zoom_index,
+                  user_data_template, geom, FALSE, numtabs, tab_pos);
 }
 
 inline static MultiWin *multi_win_new(Options *shortcuts, int zoom_index,
-				      gpointer user_data_template, int numtabs, GtkPositionType tab_pos)
+      gpointer user_data_template, int numtabs, GtkPositionType tab_pos)
 {
-	return multi_win_new_full(shortcuts, zoom_index,
-				  user_data_template, NULL, FALSE, numtabs, tab_pos);
+    return multi_win_new_full(shortcuts, zoom_index,
+                  user_data_template, NULL, FALSE, numtabs, tab_pos);
 }
 
 inline static MultiWin *multi_win_new_fullscreen(Options *shortcuts,
-						 int zoom_index, gpointer user_data_template,
-						 int numtabs, GtkPositionType tab_pos)
+                         int zoom_index, gpointer user_data_template,
+                         int numtabs, GtkPositionType tab_pos)
 {
-	return multi_win_new_full(shortcuts, zoom_index,
-				  user_data_template, NULL, TRUE, numtabs, tab_pos);
+    return multi_win_new_full(shortcuts, zoom_index,
+                  user_data_template, NULL, TRUE, numtabs, tab_pos);
 }
 
 /* Create a new window without a new child tab, ready to have an existing
  * tab moved to it. Window isn't shown yet because we don't know how big we
  * want it to be until it contains a tab. */
 MultiWin *multi_win_new_blank(Options *shortcuts, int zoom_index,
-		gpointer user_data_template, GtkPositionType tab_pos);
+        gpointer user_data_template, GtkPositionType tab_pos);
 
 void multi_win_show(MultiWin *win);
 
@@ -200,7 +206,7 @@ void multi_win_delete(MultiWin *);
 
 void
 multi_win_set_geometry_hints(MultiWin * win, GtkWidget * child,
-	GdkGeometry * geometry, GdkWindowHints geom_mask);
+    GdkGeometry * geometry, GdkWindowHints geom_mask);
 
 /* Set window size to fit child at given size */
 void
@@ -220,24 +226,26 @@ int multi_win_get_nearest_index_for_zoom(double factor);
  * popup_id and bar_id are for returning the signal handler ids returned by
  * g_signal_connect; they can be NULL if you don't need to know them */
 void
-multi_win_menu_connect_data(MultiWin * win, MenuTreeID id,
-	GCallback handler, gpointer user_data, GConnectFlags flags,
-	gulong * popup_id, gulong * bar_id);
+multi_win_menu_connect_data(MultiWin *win, MenuTreeID id,
+    GCallback handler, gpointer user_data, GConnectFlags flags,
+    gulong *popup_id, gulong *bar_id, gulong *short_pupup_id);
 
 inline static void
 multi_win_menu_connect(MultiWin * win, MenuTreeID id,
-	GCallback handler, gpointer user_data, gulong * popup_id, gulong * bar_id)
+        GCallback handler, gpointer user_data,
+        gulong *popup_id, gulong *bar_id, gulong *short_popup_id)
 {
-	multi_win_menu_connect_data(win, id, handler, user_data, 0, popup_id,
-		bar_id);
+    multi_win_menu_connect_data(win, id, handler, user_data, 0,
+            popup_id, bar_id, short_popup_id);
 }
 
 inline static void
 multi_win_menu_connect_swapped(MultiWin * win, MenuTreeID id,
-	GCallback handler, gpointer user_data, gulong * popup_id, gulong * bar_id)
+        GCallback handler, gpointer user_data,
+        gulong *popup_id, gulong *bar_id, gulong *short_popup_id)
 {
-	multi_win_menu_connect_data(win, id, handler, user_data,
-		G_CONNECT_SWAPPED, popup_id, bar_id);
+    multi_win_menu_connect_data(win, id, handler, user_data,
+        G_CONNECT_SWAPPED, popup_id, bar_id, short_popup_id);
 }
 
 MultiTab *multi_win_get_current_tab(MultiWin * win);
@@ -250,6 +258,8 @@ MenuTree *multi_win_get_menu_bar(MultiWin * win);
 
 MenuTree *multi_win_get_popup_menu(MultiWin * win);
 
+MenuTree *multi_win_get_short_popup_menu(MultiWin * win);
+
 Options *multi_win_get_shortcut_scheme(MultiWin * win);
 
 void multi_win_set_shortcut_scheme(MultiWin * win, Options *);
@@ -261,16 +271,16 @@ void
 multi_win_set_show_menu_bar(MultiWin * win, gboolean show, gboolean resize);
 
 typedef enum {
-	MultiWinScrollBar_None,
-	MultiWinScrollBar_Right,
-	MultiWinScrollBar_Left,
-	MultiWinScrollBar_Query		/* No change, just query current value */
+    MultiWinScrollBar_None,
+    MultiWinScrollBar_Right,
+    MultiWinScrollBar_Left,
+    MultiWinScrollBar_Query        /* No change, just query current value */
 } MultiWinScrollBar_Position;
 
 /* Sets scrollbar position (will be ignored if already set), and returns the
  * current value in case the new value had to be ignored */
 MultiWinScrollBar_Position multi_win_set_scroll_bar_position(MultiWin * win,
-	MultiWinScrollBar_Position new_pos);
+    MultiWinScrollBar_Position new_pos);
 
 /* Returns the window under the pointer or NULL if the window isn't a terminal
  * window owned by this app */
@@ -292,7 +302,7 @@ void multi_win_set_wrap_switch_tab(MultiWin *win, gboolean wrap);
 /* Apply a function to all tabs in one window */
 typedef void (*MultiWinForEachTabFunc)(MultiTab *tab, void *user_data);
 void multi_win_foreach_tab(MultiWin *, MultiWinForEachTabFunc,
-		gpointer user_data);
+        gpointer user_data);
 
 GtkPositionType multi_win_get_tab_pos(MultiWin *win);
 
@@ -300,11 +310,14 @@ GtkPositionType multi_win_get_tab_pos(MultiWin *win);
 extern GList *multi_win_all;
 
 /* Sets a title template string - see profile dialog "Window/Tabs Window Title"
-   comment for details; NULL is equivalent to "%s" */
-void multi_win_set_title_template(MultiWin *win, const char *tt);
+   comment for details; NULL is equivalent to "%s". If def (for "default")
+   this is a default which will be restored if NULL is subsequently passed with
+   def FALSE */
+void multi_win_set_title_template(MultiWin *win, const char *tt,
+        gboolean def);
 
-/* Returns FALSE if there are any illegal % sequences in tt */
-gboolean multi_win_validate_title_template(const char *tt);
+/* Whether window is managed by a compositor */
+gboolean multi_win_composite(MultiWin *win);
 
 #endif /* MULTITAB_H */
 
