@@ -42,6 +42,10 @@
 #define OPTSDBUS_INT_SIGNAL "IntOption"
 #define OPTSDBUS_FLOAT_SIGNAL "FloatOption"
 
+#define OPTSDBUS_SET_PROFILE "SetProfile"
+#define OPTSDBUS_SET_COLOUR_SCHEME "SetColourScheme"
+#define OPTSDBUS_SET_SHORTCUT_SCHEME "SetShortcutScheme"
+
 #ifdef ROXTERM_CAPPLET
 
 static gboolean optsdbus_read_method_arg(DBusMessage *message,
@@ -271,6 +275,42 @@ gboolean optsdbus_init(void)
 
 static OptsDBusOptionHandler optsdbus_option_handler = NULL;
 static OptsDBusStuffChangedHandler optsdbus_stuff_changed_handler = NULL;
+static OptsDBusSetProfileHandler optsdbus_set_profile_handler = NULL;
+static OptsDBusSetProfileHandler optsdbus_set_colour_scheme_handler = NULL;
+static OptsDBusSetProfileHandler optsdbus_set_shortcut_scheme_handler = NULL;
+
+static gboolean optsdbus_set_profile_callback(OptsDBusSetProfileHandler handler,
+        DBusMessage *message, DBusError *pderror)
+{
+	RTDBUS_ARG_CONST char *id_str = NULL;
+	RTDBUS_ARG_CONST char *profile_name = NULL;
+    
+    gboolean result = dbus_message_get_args(message, pderror,
+            DBUS_TYPE_STRING, &id_str,
+            DBUS_TYPE_STRING, &profile_name,
+            DBUS_TYPE_INVALID);
+    if (result)
+    {
+        void *id = NULL;
+        
+        if (sscanf(id_str, "%p", &id) == 1)
+        {
+            handler(id, profile_name);
+        }
+        else
+        {
+            dlg_warning(NULL,
+                    _("Unrecognised ROXTERM_ID '%s' in D-Bus message"), id_str);
+        }
+    }
+#if ROXTERM_DBUS_OLD_ARGS_SEMANTICS
+	if (profile_name)
+		dbus_free(profile_name);
+	if (id_str)
+		dbus_free(id_str);
+#endif
+    return result;
+}
 
 static DBusHandlerResult
 optsdbus_message_filter(DBusConnection * connection, DBusMessage * message,
@@ -281,7 +321,7 @@ optsdbus_message_filter(DBusConnection * connection, DBusMessage * message,
 	OptsDBusValue val;
 	char *dbus_str = NULL;
 	const char *signal_name;
-	gboolean args_result = FALSE;
+	gboolean args_result = TRUE;
 	DBusError derror;
 	OptsDBusOptType opt_type = OptsDBus_InvalidOpt;
 	const char *what_happened = NULL;
@@ -295,20 +335,9 @@ optsdbus_message_filter(DBusConnection * connection, DBusMessage * message,
 		return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 	}
 	signal_name = dbus_message_get_member(message);
-	if (strcmp(dbus_message_get_interface(message), OPTSDBUS_INTERFACE) ||
-		(strcmp(signal_name, OPTSDBUS_STRING_SIGNAL)
-		 && strcmp(signal_name, OPTSDBUS_INT_SIGNAL)
-		 && strcmp(signal_name, OPTSDBUS_FLOAT_SIGNAL)
-		 && strcmp(signal_name, OPTSDBUS_DELETED)
-		 && strcmp(signal_name, OPTSDBUS_ADDED)
-		 && strcmp(signal_name, OPTSDBUS_RENAMED)))
+	if (strcmp(dbus_message_get_interface(message), OPTSDBUS_INTERFACE))
 	{
-		g_warning(_("Unrecognised D-BUS signal %s.%s"),
-			dbus_message_get_interface(message),
-			dbus_message_get_member(message));
-		/* Consider it handled, because nothing else should be handling
-		 * this object */
-		return DBUS_HANDLER_RESULT_HANDLED;
+        goto bad_signal;
 	}
 
 	dbus_error_init(&derror);
@@ -342,7 +371,9 @@ optsdbus_message_filter(DBusConnection * connection, DBusMessage * message,
 		if (args_result)
 			opt_type = OptsDBus_FloatOpt;
 	}
-	else /* "stuff changed" */
+	else if (!strcmp(signal_name, OPTSDBUS_DELETED)
+             || !strcmp(signal_name, OPTSDBUS_ADDED)
+             || !strcmp(signal_name, OPTSDBUS_RENAMED))
 	{
 		what_happened = signal_name;
 		if (strcmp(signal_name, OPTSDBUS_RENAMED))
@@ -361,6 +392,34 @@ optsdbus_message_filter(DBusConnection * connection, DBusMessage * message,
 				DBUS_TYPE_INVALID);
 		}
 	}
+	else if (!strcmp(signal_name, OPTSDBUS_SET_PROFILE))
+	{
+	    if (optsdbus_set_profile_handler)
+	    {
+            args_result = optsdbus_set_profile_callback(
+                    optsdbus_set_profile_handler, message, &derror);
+        }
+	}
+	else if (!strcmp(signal_name, OPTSDBUS_SET_COLOUR_SCHEME))
+	{
+	    if (optsdbus_set_colour_scheme_handler)
+	    {
+            args_result = optsdbus_set_profile_callback(
+                    optsdbus_set_colour_scheme_handler, message, &derror);
+        }
+	}
+	else if (!strcmp(signal_name, OPTSDBUS_SET_SHORTCUT_SCHEME))
+	{
+	    if (optsdbus_set_shortcut_scheme_handler)
+	    {
+            args_result = optsdbus_set_profile_callback(
+                    optsdbus_set_shortcut_scheme_handler, message, &derror);
+        }
+	}
+	else
+	{
+	    goto bad_signal;
+	}
 	if (!args_result)
 	{
 		rtdbus_whinge(&derror, _("Unable to read D-BUS signal arguments"));
@@ -393,6 +452,12 @@ optsdbus_message_filter(DBusConnection * connection, DBusMessage * message,
 		dbus_free(new_name);
 #endif
 	return DBUS_HANDLER_RESULT_HANDLED;
+bad_signal:
+    g_warning(_("Unrecognised D-BUS signal %s.%s"),
+        dbus_message_get_interface(message), signal_name);
+    /* Consider it handled, because nothing else should be handling
+     * this object */
+    return DBUS_HANDLER_RESULT_HANDLED;
 }
 
 static void optsdbus_enable_filter(void)
@@ -403,7 +468,7 @@ static void optsdbus_enable_filter(void)
 		return;
 	enabled = TRUE;
 	rtdbus_add_signal_rule_and_filter(
-			OPTSDBUS_NAME, OPTSDBUS_OBJECT_PATH, OPTSDBUS_INTERFACE,
+			OPTSDBUS_OBJECT_PATH, OPTSDBUS_INTERFACE,
 			optsdbus_message_filter);
 }
 
@@ -420,6 +485,26 @@ void optsdbus_listen_for_stuff_changed_signals(
 	optsdbus_stuff_changed_handler = handler;
 }
 
+void optsdbus_listen_for_set_profile_signals(OptsDBusSetProfileHandler handler)
+{
+    optsdbus_enable_filter();
+    optsdbus_set_profile_handler = handler;
+}
+
+void optsdbus_listen_for_set_colour_scheme_signals(
+        OptsDBusSetProfileHandler handler)
+{
+    optsdbus_enable_filter();
+    optsdbus_set_colour_scheme_handler = handler;
+}
+
+void optsdbus_listen_for_set_shortcut_scheme_signals(
+        OptsDBusSetProfileHandler handler)
+{
+    optsdbus_enable_filter();
+    optsdbus_set_shortcut_scheme_handler = handler;
+}
+
 gboolean optsdbus_send_edit_opts_message(const char *method, const char *arg)
 {
 	GError *error = NULL;
