@@ -51,12 +51,16 @@ struct ProfileGUI {
 	gboolean ignore_destroy;
 	struct {
 		char sel_by_word;
+		/*char emulation;*/
 		char browser;
 		char mailer;
 		char command;
 		char title_string;
 	} changed;
 	GtkWidget *bgimg;
+#ifndef HAVE_VTE_TERMINAL_SET_CURSOR_BLINK_MODE
+	GtkWidget *cursor_blinks;
+#endif
 	DragReceiveData *bgimg_drd;
 };
 
@@ -81,6 +85,13 @@ void profilegui_check_entries_for_changes(ProfileGUI * pg)
 		profilegui_update_from_entry(pg, "sel_by_word");
 		pg->changed.sel_by_word = 0;
 	}
+	/*
+	if (pg->changed.emulation)
+	{
+		profilegui_update_from_entry(pg, "emulation");
+		pg->changed.emulation = 0;
+	}
+	*/
 	if (pg->changed.browser)
 	{
 		profilegui_update_from_entry(pg, "browser");
@@ -202,6 +213,19 @@ static void on_custom_command_toggled(GtkToggleButton *button, ProfileGUI *pg)
 	on_boolean_toggled(button, pg->profile);
 }
 
+#ifndef HAVE_VTE_TERMINAL_SET_CURSOR_BLINK_MODE
+static void on_cursor_blinks_toggled(GtkToggleButton *button, Options *opts)
+{
+    gboolean state;
+    
+	if (capplet_ignore_changes)
+		return;
+    
+    state = gtk_toggle_button_get_active(button);
+    capplet_set_int(opts, "cursor_blinks", state);
+}
+#endif
+
 #define PREVIEW_SIZE 160
 
 inline static gboolean pg_image_reportable(ProfileGUI *pg)
@@ -393,6 +417,11 @@ static gboolean bgimg_drag_data_received(GtkWidget *widget,
 	return result;
 }
 
+static void exit_action_changed(GtkComboBox *combo, ProfileGUI *pg)
+{
+    gtk_widget_set_sensitive(profilegui_widget(pg, "exit_pause"),
+            gtk_combo_box_get_active(combo) != 3);
+}
 
 /***********************************************************/
 
@@ -410,6 +439,7 @@ static void profilegui_connect_handlers(ProfileGUI * pg)
 
 	/* Editables */
 	PG_EC_CONNECT(pg, sel_by_word);
+	/*PG_EC_CONNECT(pg, emulation);*/
 	PG_EC_CONNECT(pg, command);
 	PG_EC_CONNECT(pg, browser);
 	PG_EC_CONNECT(pg, mailer);
@@ -438,6 +468,12 @@ static void profilegui_connect_handlers(ProfileGUI * pg)
 	PG_CONNECT(pg, on_bgimg_browse_clicked);
 #endif
 	PG_CONNECT(pg, on_reset_compat_clicked);
+#ifndef HAVE_VTE_TERMINAL_SET_CURSOR_BLINK_MODE
+    g_signal_connect(pg->cursor_blinks, "toggled",
+            G_CALLBACK(on_cursor_blinks_toggled), pg->profile);
+#endif
+    g_signal_connect(profilegui_widget(pg, "exit_action"), "changed",
+            G_CALLBACK(exit_action_changed), pg);
 }
 
 static void profilegui_fill_in_dialog(ProfileGUI * pg)
@@ -457,9 +493,27 @@ static void profilegui_fill_in_dialog(ProfileGUI * pg)
 	capplet_set_boolean_toggle(glade, profile, "allow_bold", TRUE);
 	capplet_set_boolean_toggle(glade, profile, "audible_bell", TRUE);
 	capplet_set_boolean_toggle(glade, profile, "visible_bell", FALSE);
-	capplet_set_boolean_toggle(glade, profile, "cursor_blinks", FALSE);
+	capplet_set_boolean_toggle(glade, profile, "bell_highlights_tab", TRUE);
+#ifdef HAVE_VTE_TERMINAL_SET_CURSOR_BLINK_MODE
+    {
+        /* Use legacy cursor_blinks if cursor_blink_mode has not been set */
+        int o = options_lookup_int(profile, "cursor_blinks") + 1;
+        if (o)
+            o ^= 3;
+        capplet_set_radio(glade, profile, "cursor_blink_mode", o);
+	}
+#else
+    capplet_ignore_changes = TRUE;
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pg->cursor_blinks),
+	        options_lookup_int_with_default(profile, "cursor_blinks", FALSE));
+	capplet_ignore_changes = FALSE;
+#endif
+#ifdef HAVE_VTE_TERMINAL_SET_CURSOR_SHAPE
+	capplet_set_radio(glade, profile, "cursor_shape", 0);
+#endif
 	capplet_set_boolean_toggle(glade, profile, "hide_mouse", TRUE);
 	capplet_set_text_entry(glade, profile, "sel_by_word", "-A-Za-z0-9,./?%&#_");
+	/*capplet_set_text_entry(glade, profile, "emulation", NULL);*/
 	capplet_set_boolean_toggle(glade, profile, "wrap_switch_tab", FALSE);
 	capplet_set_text_entry(glade, profile, "browser", NULL);
 	capplet_set_radio(glade, profile, "browser_spawn_type", 0);
@@ -478,6 +532,7 @@ static void profilegui_fill_in_dialog(ProfileGUI * pg)
 #else
 	capplet_set_text_entry(glade, profile, "background_img", NULL);
 #endif
+	capplet_set_boolean_toggle(glade, profile, "true_translucence", TRUE);
 	capplet_set_radio(glade, profile, "scrollbar_pos", 1);
 	capplet_set_spin_button(glade, profile, "scrollback_lines", 1000);
 	capplet_set_boolean_toggle(glade, profile, "scroll_on_output", FALSE);
@@ -498,6 +553,8 @@ static void profilegui_fill_in_dialog(ProfileGUI * pg)
 	capplet_set_combo(glade, profile, "tab_pos", 0);
 	capplet_set_spin_button_float(glade, profile, "exit_pause");
 	capplet_set_text_entry(glade, profile, "title_string", "%s");
+    exit_action_changed(GTK_COMBO_BOX(profilegui_widget(pg, "exit_action")),
+            pg);
 	profilegui_set_command_shading(pg);
 }
 
@@ -505,7 +562,7 @@ static void profilegui_fill_in_dialog(ProfileGUI * pg)
 /* For backwards compatibility with older GTKs the glade file uses a text entry
  * and a button for choosing a background image file. This function replaces
  * them with a GtkFileChooserButton. */
-void profilegui_replace_file_chooser_widgets(ProfileGUI *pg)
+static void profilegui_replace_file_chooser_widgets(ProfileGUI *pg)
 {
 	GtkWidget *hbox = profilegui_widget(pg, "background_img_box");
 	GtkWidget *entry = profilegui_widget(pg, "background_img");
@@ -521,6 +578,37 @@ void profilegui_replace_file_chooser_widgets(ProfileGUI *pg)
 }
 #endif
 
+#if !defined HAVE_VTE_TERMINAL_SET_CURSOR_BLINK_MODE || \
+        !defined HAVE_VTE_TERMINAL_SET_CURSOR_SHAPE
+static void profilegui_destroy_radio_group_and_label(ProfileGUI *pg,
+        const char *group_name)
+{
+    int n;
+    char *name = g_strdup_printf("%s_label", group_name);
+    
+    gtk_widget_destroy(profilegui_widget(pg, name));
+    g_free(name);
+    for (n = 0; n < 3; ++n)
+    {
+        name = g_strdup_printf("%s%d", group_name, n);
+        gtk_widget_destroy(profilegui_widget(pg, name));
+        g_free(name);
+    }
+}
+#endif
+
+#ifndef HAVE_VTE_TERMINAL_SET_CURSOR_BLINK_MODE
+static void profilegui_replace_blink_mode_widgets(ProfileGUI *pg)
+{
+	GtkWidget *table = profilegui_widget(pg, "general_table");
+    
+    profilegui_destroy_radio_group_and_label(pg, "cursor_blink_mode");
+	pg->cursor_blinks = gtk_check_button_new_with_mnemonic(_("Cursor blin_ks"));
+	gtk_widget_show(pg->cursor_blinks);
+    gtk_table_attach_defaults(GTK_TABLE(table), pg->cursor_blinks, 2, 3, 2, 3);
+}
+#endif
+
 /* Loads a Profile and creates a working dialog box for it */
 ProfileGUI *profilegui_open(const char *profile_name)
 {
@@ -559,6 +647,12 @@ ProfileGUI *profilegui_open(const char *profile_name)
 
 	g_hash_table_insert(profilegui_being_edited, g_strdup(profile_name), pg);
 
+#ifndef HAVE_VTE_TERMINAL_SET_CURSOR_BLINK_MODE
+    profilegui_replace_blink_mode_widgets(pg);
+#endif
+#ifndef HAVE_VTE_TERMINAL_SET_CURSOR_SHAPE
+    profilegui_destroy_radio_group_and_label(pg, "cursor_shape");
+#endif
 #ifdef HAVE_GTK_FILE_CHOOSER_BUTTON_NEW
 	profilegui_replace_file_chooser_widgets(pg);
 #else
